onDragCanceled property
Called when a drag gesture is canceled.
The bool indicates whether the user moved their finger or not.
Implementation
final PartDayDragCanceledCallbackRaw? onDragCanceled;
Called when a drag gesture is canceled.
The bool indicates whether the user moved their finger or not.
final PartDayDragCanceledCallbackRaw? onDragCanceled;